@@ -1,11 +1,12 @@
 """
-Text tokenization methods
+Tokenizer module
 """
 
 import re
 import string
 
-class Tokenizer(object):
+
+class Tokenizer:
     """
     Text tokenization methods
     """
@@ -13,10 +14,12 @@ class Tokenizer(object):
     # Use standard python punctuation chars but allow tokens to end in # (to allow c#, f#) and + to allow (c++ g++)
     PUNCTUATION = string.punctuation.replace("#", "").replace("+", "")
 
+    # fmt: off
     # English Stop Word List (Standard stop words used by Apache Lucene)
     STOP_WORDS = {"a", "an", "and", "are", "as", "at", "be", "but", "by", "for", "if", "in", "into", "is", "it",
                   "no", "not", "of", "on", "or", "such", "that", "the", "their", "then", "there", "these",
                   "they", "this", "to", "was", "will", "with"}
+    # fmt: on
 
     @staticmethod
     def tokenize(text):
@@ -35,4 +38,9 @@ class Tokenizer(object):
 
         # Filter tokens that are numbers or a valid string at least 2 characters long. Remove stop words.
         # Assume tokens already are uncased (all lowercase)
-        return [token for token in tokens if (re.match(r"^[#*+\-.0-9:@_a-z]{2,}$", token) or token.isdigit()) and token not in Tokenizer.STOP_WORDS]
+        return [
+            token
+            for token in tokens
+            if (re.match(r"^[#*+\-.0-9:@_a-z]{2,}$", token) or token.isdigit())
+            and token not in Tokenizer.STOP_WORDS
+        ]
